@@ -9,6 +9,7 @@ from typing import Any, Optional, Set
 import torch
 from pytorch_lightning import Callback, LightningModule, Trainer
 from pytorch_lightning.utilities.distributed import rank_zero_only
+from pytorch_lightning.utilities.types import STEP_OUTPUT
 
 
 class EpochTimers:
@@ -211,7 +212,7 @@ class BatchTimeCallback(Callback):
         self.write_and_log_epoch_time(is_training=True)
         self.write_and_log_epoch_time(is_training=False)
 
-    def on_train_batch_start(self,
+    def on_train_batch_start(self,  # type: ignore
                              trainer: Trainer,
                              pl_module: LightningModule,
                              batch: Any,
@@ -229,7 +230,7 @@ class BatchTimeCallback(Callback):
                                   ) -> None:
         self.batch_start(batch_idx=batch_idx, is_training=False)
 
-    def on_train_batch_end(self,
+    def on_train_batch_end(self,  # type: ignore
                            trainer: Trainer,
                            pl_module: LightningModule,
                            outputs: Any,
@@ -337,3 +338,88 @@ class BatchTimeCallback(Callback):
         Gets the object that holds all metrics and timers, for either the validation or the training epoch.
         """
         return self.train_timers if is_training else self.val_timers
+
+
+class TrainingDiagnoticsCallback(Callback):
+    """Callback that logs information about the training process."""
+
+    def on_train_epoch_start(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        logging.info(f"Reached on_train_epoch_start on global rank {pl_module.global_rank}")
+
+    def on_train_epoch_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        logging.info(f"Reached on_train_epoch_end on global rank {pl_module.global_rank}")
+
+    def on_validation_epoch_start(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        logging.info(f"Reached on_validation_epoch_start on global rank {pl_module.global_rank}")
+
+    def on_validation_epoch_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        logging.info(f"Reached on_validation_epoch_end on global rank {pl_module.global_rank}")
+
+    def on_test_epoch_start(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        logging.info(f"Reached on_test_epoch_start on global rank {pl_module.global_rank}")
+
+    def on_test_epoch_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        logging.info(f"Reached on_test_epoch_end on global rank {pl_module.global_rank}")
+
+    def on_train_start(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        logging.info(f"Reached on_train_start on global rank {pl_module.global_rank}")
+
+    def on_train_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        logging.info(f"Reached from on_train_end on global rank {pl_module.global_rank}")
+
+    def on_validation_start(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        logging.info(f"Reached from on_validation_start on global rank {pl_module.global_rank}")
+
+    def on_validation_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        logging.info(f"Reached from on_validation_end on global rank {pl_module.global_rank}")
+
+    def on_test_start(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        logging.info(f"Reached from on_test_start on global rank {pl_module.global_rank}")
+
+    def on_test_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
+        logging.info(f"Reached from on_test_end on global rank {pl_module.global_rank}")
+
+    def on_train_batch_start(
+        self, trainer: Trainer, pl_module: LightningModule, batch: Any, batch_idx: int, unused: int = 0
+    ) -> None:
+        logging.info(
+            f"Reached from on_train_batch_start on global rank {pl_module.global_rank} for batch_idx {batch_idx}"
+        )
+
+    def on_train_batch_end(
+        self, trainer: Trainer, pl_module: LightningModule, outputs: STEP_OUTPUT, batch: Any, batch_idx: int,
+        unused: int = 0
+    ) -> None:
+        logging.info(
+            f"Reached from on_train_batch_end on global rank {pl_module.global_rank} for batch_idx {batch_idx}"
+        )
+
+    def on_validation_batch_start(
+        self, trainer: Trainer, pl_module: LightningModule, batch: Any, batch_idx: int, unused: int = 0
+    ) -> None:
+        logging.info(
+            f"Reached from on_validation_batch_start on global rank {pl_module.global_rank} for batch_idx {batch_idx}"
+        )
+
+    def on_validation_batch_end(
+        self, trainer: Trainer, pl_module: LightningModule, outputs: Optional[STEP_OUTPUT], batch: Any, batch_idx: int,
+        dataloader_idx: int
+    ) -> None:
+        logging.info(
+            f"Reached from on_validation_batch_end on global rank {pl_module.global_rank} for batch_idx {batch_idx}"
+        )
+
+    def on_test_batch_end(
+        self, trainer: Trainer, pl_module: LightningModule, outputs: Optional[STEP_OUTPUT], batch: Any, batch_idx: int,
+        dataloader_idx: int
+    ) -> None:
+        logging.info(
+            f"Reached from on_test_batch_end on global rank {pl_module.global_rank} for batch_idx {batch_idx}"
+        )
+
+    def on_test_batch_start(
+        self, trainer: Trainer, pl_module: LightningModule, batch: Any, batch_idx: int, unused: int = 0
+    ) -> None:
+        logging.info(
+            f"Reached from on_test_batch_start on global rank {pl_module.global_rank} for batch_idx {batch_idx}"
+        )
